@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.2103';
+our $VERSION = '0.2104';
 
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
@@ -494,7 +494,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2103
+version 0.2104
 
 =head1 SYNOPSIS
 
@@ -510,21 +510,21 @@ version 0.2103
  $g->row_reduce();
  $g->col_reduce();
  my $player = 1;
- my $p = $g->saddlepoint();
+ my $s = $g->saddlepoint();
  my $o = $g->oddments();
  my $e = $g->expected_payoff();
  my $c = $g->counter_strategy($player);
- my $u = $g->play();
+ my $p = $g->play();
 
  $g = Game::Theory::TwoPersonMatrix->new(
     1 => { 1 => 0.1, 2 => 0.2, 3 => 0.7 },
     2 => { 1 => 0.1, 2 => 0.2, 3 => 0.3, 4 => 0.4 },
     # Payoff table for the row player
-    payoff1 => [ [5,3,8,2],   # 1
+    payoff1 => [ [5,3,8,2],   # 1st strategy
                  [6,5,7,1],   # 2
                  [7,4,6,0] ], # 3
     # Payoff table for the column player (opponent)
-    #             1 2 3 4
+    #             1 2 3 4th strategy
     payoff2 => [ [2,0,1,3],
                  [3,4,4,1],
                  [5,6,8,2] ],
@@ -534,7 +534,7 @@ version 0.2103
  my $n = $g->nash();
  $e = $g->expected_payoff();
  $c = $g->counter_strategy($player);
- $u = $g->play();
+ $p = $g->play();
 
 =head1 DESCRIPTION
 
@@ -691,21 +691,25 @@ for its row.
  $u = $g->play();
  $u = $g->play(%strategies);
 
-Return a single outcome for a zero-sum game or a pair for a non-zero-sum game.
+Return a single outcome for a zero-sum game, or a pair for a non-zero-sum game
+as a hashref keyed by each strategy chosen and with values of the payoff(s)
+earned.
 
-An optional list of player strategies can be provided.  This is a hashref of the
+An optional list of player strategies can be provided.  This is a hash of the
 same type of strategies that are given to the constructor.
 
 =head1 SEE ALSO
 
 The F<eg/> and F<t/> scripts in this distribution.
 
-"A Gentle Introduction to Game Theory"
+"A Gentle Introduction to Game Theory" from which this API is derived:
 
 L<http://www.amazon.com/Gentle-Introduction-Theory-Mathematical-World/dp/0821813390>
 
 L<http://books.google.com/books?id=8doVBAAAQBAJ>
 
+L<https://en.wikipedia.org/wiki/Prisoner%27s_dilemma>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
